@@ -1,4 +1,4 @@
-# Copyright 2021 ONDEWO GmbH
+# Copyright 2021-2025 ONDEWO GmbH
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,6 +11,12 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from typing import (
+    Any,
+    Optional,
+    Set,
+    Tuple,
+)
 
 from ondewo.utils.base_client import BaseClient
 from ondewo.utils.base_client_config import BaseClientConfig
@@ -24,13 +30,24 @@ class Client(BaseClient):
     The core python client for interacting with ONDEWO SIP services.
     """
 
-    def _initialize_services(self, config: BaseClientConfig, use_secure_channel: bool) -> None:
+    def _initialize_services(
+        self,
+        config: BaseClientConfig,
+        use_secure_channel: bool,
+        options: Optional[Set[Tuple[str, Any]]] = None,
+    ) -> None:
         """
-        Login with the current config and setup the services in self.services
 
-        Returns:
-            None
+        Initialize the service clients and lLogin with the current config and set up the services in self.services
+
+        Args:
+            config (BaseClientConfig):
+                Configuration for the client.
+            use_secure_channel (bool):
+                Whether to use a secure gRPC channel.
+            options (Optional[Set[Tuple[str, Any]]]):
+                Additional options for the gRPC channel.
         """
         self.services: ServicesContainer = ServicesContainer(
-            sip=Sip(config=config, use_secure_channel=use_secure_channel),
+            sip=Sip(config=config, use_secure_channel=use_secure_channel, options=options),
         )
